==> odata-client-microsoft-dynamics-0.1.39-sources.jar: microsoft/dynamics/crm/complex/RelationshipAttribute.java <==
package microsoft.dynamics.crm.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.Checks;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "ReferencingAttributeName", 
    "ReferencedAttributeName"})
@JsonInclude(Include.NON_NULL)
public class RelationshipAttribute implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected ContextPath contextPath;

    @JacksonInject
    @JsonIgnore
    protected UnmappedFieldsImpl unmappedFields;

    @JsonProperty("@odata.type")
    protected String odataType;

    @JsonProperty("ReferencingAttributeName")
    protected String referencingAttributeName;

    @JsonProperty("ReferencedAttributeName")
    protected String referencedAttributeName;

    protected RelationshipAttribute() {
    }

    @Override
    public String odataTypeName() {
        return "Microsoft.Dynamics.CRM.RelationshipAttribute";
    }

    @Property(name="ReferencingAttributeName")
    @JsonIgnore
    public Optional<String> getReferencingAttributeName() {
        return Optional.ofNullable(referencingAttributeName);
    }

    public RelationshipAttribute withReferencingAttributeName(String referencingAttributeName) {
        Checks.checkIsAscii(referencingAttributeName);
        RelationshipAttribute _x = _copy();
        _x.odataType = Util.nvl(odataType, "Microsoft.Dynamics.CRM.RelationshipAttribute");
        _x.referencingAttributeName = referencingAttributeName;
        return _x;
    }

    @Property(name="ReferencedAttributeName")
    @JsonIgnore
    public Optional<String> getReferencedAttributeName() {
        return Optional.ofNullable(referencedAttributeName);
    }

    public RelationshipAttribute withReferencedAttributeName(String referencedAttributeName) {
        Checks.checkIsAscii(referencedAttributeName);
        RelationshipAttribute _x = _copy();
        _x.odataType = Util.nvl(odataType, "Microsoft.Dynamics.CRM.RelationshipAttribute");
        _x.referencedAttributeName = referencedAttributeName;
        return _x;
    }

    public RelationshipAttribute withUnmappedField(String name, String value) {
        RelationshipAttribute _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builder() {
        return new Builder();
    }

    public static final class Builder {
        private String referencingAttributeName;
        private String referencedAttributeName;
        private ChangedFields changedFields = new ChangedFields();

        Builder() {
            // prevent instantiation
        }

        public Builder referencingAttributeName(String referencingAttributeName) {
            this.referencingAttributeName = referencingAttributeName;
            this.changedFields = changedFields.add("ReferencingAttributeName");
            return this;
        }

        public Builder referencedAttributeName(String referencedAttributeName) {
            this.referencedAttributeName = referencedAttributeName;
            this.changedFields = changedFields.add("ReferencedAttributeName");
            return this;
        }

        public RelationshipAttribute build() {
            RelationshipAttribute _x = new RelationshipAttribute();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "Microsoft.Dynamics.CRM.RelationshipAttribute";
            _x.referencingAttributeName = referencingAttributeName;
            _x.referencedAttributeName = referencedAttributeName;
            return _x;
        }
    }

    private RelationshipAttribute _copy() {
        RelationshipAttribute _x = new RelationshipAttribute();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.referencingAttributeName = referencingAttributeName;
        _x.referencedAttributeName = referencedAttributeName;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("RelationshipAttribute[");
        b.append("ReferencingAttributeName=");
        b.append(this.referencingAttributeName);
        b.append(", ");
        b.append("ReferencedAttributeName=");
        b.append(this.referencedAttributeName);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}

==> odata-client-microsoft-dynamics-0.1.75-sources.jar: microsoft/dynamics/crm/complex/RelationshipAttribute.java <==
package microsoft.dynamics.crm.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.Checks;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "ReferencingAttributeName", 
    "ReferencedAttributeName"})
@JsonInclude(Include.NON_NULL)
public class RelationshipAttribute implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected ContextPath contextPath;

    @JacksonInject
    @JsonIgnore
    protected UnmappedFieldsImpl unmappedFields;

    @JsonProperty("@odata.type")
    protected String odataType;

    @JsonProperty("ReferencingAttributeName")
    protected String referencingAttributeName;

    @JsonProperty("ReferencedAttributeName")
    protected String referencedAttributeName;

    protected RelationshipAttribute() {
    }

    @Override
    public String odataTypeName() {
        return "Microsoft.Dynamics.CRM.RelationshipAttribute";
    }

    @Property(name="ReferencingAttributeName")
    @JsonIgnore
    public Optional<String> getReferencingAttributeName() {
        return Optional.ofNullable(referencingAttributeName);
    }

    public RelationshipAttribute withReferencingAttributeName(String referencingAttributeName) {
        Checks.checkIsAscii(referencingAttributeName);
        RelationshipAttribute _x = _copy();
        _x.odataType = Util.nvl(odataType, "Microsoft.Dynamics.CRM.RelationshipAttribute");
        _x.referencingAttributeName = referencingAttributeName;
        return _x;
    }

    @Property(name="ReferencedAttributeName")
    @JsonIgnore
    public Optional<String> getReferencedAttributeName() {
        return Optional.ofNullable(referencedAttributeName);
    }

    public RelationshipAttribute withReferencedAttributeName(String referencedAttributeName) {
        Checks.checkIsAscii(referencedAttributeName);
        RelationshipAttribute _x = _copy();
        _x.odataType = Util.nvl(odataType, "Microsoft.Dynamics.CRM.RelationshipAttribute");
        _x.referencedAttributeName = referencedAttributeName;
        return _x;
    }

    public RelationshipAttribute withUnmappedField(String name, String value) {
        RelationshipAttribute _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builder() {
        return new Builder();
    }

    public static final class Builder {
        private String referencingAttributeName;
        private String referencedAttributeName;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        public Builder referencingAttributeName(String referencingAttributeName) {
            this.referencingAttributeName = referencingAttributeName;
            this.changedFields = changedFields.add("ReferencingAttributeName");
            return this;
        }

        public Builder referencedAttributeName(String referencedAttributeName) {
            this.referencedAttributeName = referencedAttributeName;
            this.changedFields = changedFields.add("ReferencedAttributeName");
            return this;
        }

        public RelationshipAttribute build() {
            RelationshipAttribute _x = new RelationshipAttribute();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "Microsoft.Dynamics.CRM.RelationshipAttribute";
            _x.referencingAttributeName = referencingAttributeName;
            _x.referencedAttributeName = referencedAttributeName;
            return _x;
        }
    }

    private RelationshipAttribute _copy() {
        RelationshipAttribute _x = new RelationshipAttribute();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.referencingAttributeName = referencingAttributeName;
        _x.referencedAttributeName = referencedAttributeName;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("RelationshipAttribute[");
        b.append("ReferencingAttributeName=");
        b.append(this.referencingAttributeName);
        b.append(", ");
        b.append("ReferencedAttributeName=");
        b.append(this.referencedAttributeName);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}
